LoyaltyCardResult class

Constructors

LoyaltyCardResult({required bool success, String? data, int? errorCode, String? errorMessage})
LoyaltyCardResult.fromMap(dynamic map)
factory

Properties

data → String?
final
errorCode → int?
final
errorMessage → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited