FlutterTappa class
FlutterTappa provides access to the Tappa NFC payment SDK for Android.
Constructors
- FlutterTappa()
-
Factory constructor that returns the singleton instance
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
loyaltyCardStream
→ Stream<
LoyaltyCardResult> -
Create a stream for loyalty card results
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearCallbacks(
) → void - Clears the registered callbacks (useful for cleanup)
-
initialize(
{required TappaErrorCallback errorCallback, TappaLoyaltyCardCallback? loyaltyCardCallback, bool isSandBoxMode = true}) → Future< bool> - Initializes the Tappa SDK.
-
initTerminal(
{required String terminalId, required String uniqueId, required String clientId, required String merchantLocation}) → Future< void> - Initializes the terminal with merchant and identification details.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processQrAndTransact(
{required String qrData, required String amount, required String accountType, required String rrn}) → Future< EmvQrData?> - Processes the QR data and performs an EMV transaction in a single operation.
-
processQrForResult(
String qrData) → Future< EmvQrData?> - Processes a QR code and returns the parsed EMV transaction data.
-
startReadingLoyaltyCard(
) → Future< bool> - Start the loyalty card reading process
-
toString(
) → String -
A string representation of this object.
inherited
-
transact(
{required String amount, required String accountType, required String rrn}) → Future< void> - Starts a payment transaction using NFC.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited